@@ -5,17 +5,19 @@ use warnings;
 use Carp;
 use Email::Valid ();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 Data::RuledValidator->add_condition_operator
   (
    'num'      => sub{my($self, $v) = @_; return $v =~/^\d+$/},
+   'number'   => sub{my($self, $v) = @_; return $v =~/^\d+$/},
    'alpha'    => sub{my($self, $v) = @_; return $v =~/^[a-zA-Z]+$/},
    'alphanum' => sub{my($self, $v) = @_; return $v =~/^[a-zA-Z0-9]+$/},
    'word'     => sub{my($self, $v) = @_; return $v =~/^\w+$/},
-   'any'      => sub{my($self, $v) = @_; return defined $v},
-   'null'     => sub{my($self, $v) = @_; return not defined $v or $v eq ''},
    'words'    => sub{my($self, $v) = @_; return $v =~/^[\w\s]+$/},
+   'any'      => sub{my($self, $v) = @_; return defined $v and $v ne ''},
+   'not_null' => sub{my($self, $v) = @_; return defined $v and $v ne ''},
+   'null'     => sub{my($self, $v) = @_; return not defined $v or $v eq ''},
   );
 
 1;
@@ -26,16 +28,61 @@ __END__
 
 Data::RuledValidator::Plugin::Core - Data::RuldedValidator core plugins
 
-=head1 SYNOPSIS
+=head1 PROVIDED CONDITIONS
 
-=head1 DESCRIPTION
+=over 4
 
-=head2 EXPORT
+=item num, number
+
+ key is num
+ key is number
+
+=item alpha
+
+ key is alpha
+
+key is alphabet
+
+=item alphanum
+
+ key is alphanum
+
+key is alphabet and number.
+
+=item word
+
+ key is word
+
+key matches \w
+
+=item words
+
+ key is words
+
+key matches \w and \s
+
+=item any, not_null
+
+ key is any
+ key is not_null
+
+key is any value. null value is invalid.
+
+=item null
+
+ key is null
+
+key is null.
+
+=back
 
 =head1 SEE ALSO
 
-=head1 COPYRIGHT AND LICENSE
+=over 4
 
+=item * Data::RuledValidator
+
+=back
 
 =head1 AUTHOR
 
